/**
 * Initial paramter parse to handle conditionally starting as a persistent process (e.g. daemon mode)
 * @export
 * @class Processor
 */
export declare class Processor {
    private mParms;
    /**
     * Default port number
     * @private
     * @static
     * @memberof Processor
     */
    private static readonly DEFAULT_PORT;
    /**
     * Undocumented paramter for launching in server mode
     * @private
     * @static
     * @memberof Processor
     */
    private static readonly DAEMON_KEY;
    /**
     * Hold instance of a running server
     * @private
     * @type {net.Server}
     * @memberof Processor
     */
    private mServer;
    /**
     * Hold current port number for the server
     * @private
     * @type {number}
     * @memberof Processor
     */
    private mPort;
    /**
     * Indicator for whether or not to start the server
     * @private
     * @type {boolean}
     * @memberof Processor
     */
    private mStartServer;
    /**
     * Creates an instance of Processor.
     * @param {string[]} mParms
     * @memberof Processor
     */
    constructor(mParms: string[]);
    /**
     * Initialize our processor parse and optionally start the server
     * @memberof Processor
     */
    init(): void;
    /**
     * Method to immediately parse or otherwise start the server for later processing from
     * incoming socket connections.
     * @memberof Processor
     */
    process(): void;
    /**
     * Server close handler
     * @private
     * @memberof Processor
     */
    private close;
    /**
     * Server error handler
     * @private
     * @param {Error} err
     * @memberof Processor
     */
    private error;
    /**
     * Perform initial parsing of undocumented parameters
     * @private
     * @memberof Processor
     */
    private initialParse;
    /**
     * Get whether or not to start the server
     * @private
     * @memberof Processor
     */
    private get startServer();
    /**
     * Set whether or not to start the server
     * @private
     * @memberof Processor
     */
    private set startServer(value);
}
